"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts = require("typescript");
let currentRoot;
exports.default = {
    getRootNode(source, fileName = '') {
        return ts.createSourceFile(fileName, source, ts.ScriptTarget.ESNext);
    },
    walkNodes(root, visit) {
        currentRoot = root;
        this.walkChildNodes(root, visit);
        currentRoot = undefined;
    },
    walkChildNodes(node, visit) {
        visit(node);
        ts.forEachChild(node, child => {
            this.walkChildNodes(child, visit);
        });
    },
    isTaggedTemplate: ts.isTaggedTemplateExpression,
    getTagText(node) {
        return node.tag.getText(currentRoot);
    },
    getTaggedTemplateTemplate(node) {
        return node.template;
    },
    isTemplate: ts.isTemplateLiteral,
    getTemplateParts(node) {
        if (ts.isNoSubstitutionTemplateLiteral(node)) {
            let fullText = node.getFullText(currentRoot);
            let startOffset = 1;
            while (fullText.startsWith(' ')) {
                fullText = fullText.slice(1);
                startOffset++;
            }
            // "`string`"
            return [
                {
                    text: node.text,
                    start: node.pos + startOffset,
                    end: node.end - 1
                }
            ];
        }
        else {
            return [
                // "`head${" "}middle${" "}tail`"
                {
                    text: node.head.text,
                    start: node.head.pos + 1,
                    end: node.head.end - 2
                },
                ...node.templateSpans.map(templateSpan => {
                    const literal = templateSpan.literal;
                    return {
                        text: literal.text,
                        start: literal.pos + 1,
                        end: literal.end - (ts.isTemplateMiddle(literal) ? 2 : 1)
                    };
                })
            ];
        }
    }
};
//# sourceMappingURL=typescript.js.map